==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/WebFloatingPaneResizeEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebFloatingPaneResizeEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebFloatingPaneResizeEventArgsDescription, _super);
    function WebFloatingPaneResizeEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        return _this;
    }
    WebFloatingPaneResizeEventArgsDescription.prototype.get_type = function () {
        return "WebFloatingPaneResizeEventArgs";
    };
    Object.defineProperty(WebFloatingPaneResizeEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebFloatingPaneResizeEventArgsDescription.prototype, "detail", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Detail");
        },
        enumerable: true,
        configurable: true
    });
    WebFloatingPaneResizeEventArgsDescription.$t = markType(WebFloatingPaneResizeEventArgsDescription, 'WebFloatingPaneResizeEventArgsDescription', Description.$);
    return WebFloatingPaneResizeEventArgsDescription;
}(Description));
export { WebFloatingPaneResizeEventArgsDescription };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebFloatingPaneResizeEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebFloatingPaneResizeEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebFloatingPaneResizeEventArgsDescription, _super);
    function WebFloatingPaneResizeEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        _this.h = null;
        return _this;
    }
    WebFloatingPaneResizeEventArgsDescription.prototype.get_type = function () {
        return "WebFloatingPaneResizeEventArgs";
    };
    Object.defineProperty(WebFloatingPaneResizeEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebFloatingPaneResizeEventArgsDescription.prototype, "sourcePane", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("SourcePane");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebFloatingPaneResizeEventArgsDescription.prototype, "resizerLocation", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("ResizerLocation");
        },
        enumerable: true,
        configurable: true
    });
    WebFloatingPaneResizeEventArgsDescription.$t = markType(WebFloatingPaneResizeEventArgsDescription, 'WebFloatingPaneResizeEventArgsDescription', Description.$);
    return WebFloatingPaneResizeEventArgsDescription;
}(Description));
export { WebFloatingPaneResizeEventArgsDescription };
